Module client

Module client 

Client for listening to item and menu events, and associated types.

Structs

Client
Client for watching the tray.

Enums

ActivateRequest
A request to ‘activate’ one of the menu items, typically sent when it is clicked.
Event
An event emitted by the client representing a change from either the StatusNotifierItem or DBusMenu protocols.
UpdateEvent
The specific change associated with an update event.